# WARNING: Synchronized with Fedora!

# Mageia does not currently have a Koji instance
# available on its infrastructure yet, so for now,
# the patch for using it with the koji CLI client is
# disabled. (ngompa)
%bcond_with use_mga_cli_cfg

Name: koji
Version: 1.23.0
Release: %mkrel 1
License: LGPLv2
Summary: Build system tools
Group: System/Packaging
URL: https://koji.build/

Source: https://releases.pagure.org/%{name}/%{name}-%{version}.tar.bz2

# Patches from upstream

# Patches proposed upstream
## Fix install of koji Python code
## From: https://pagure.io/koji/pull-request/2579
Patch0501: koji-PR2579-Install-into-usr-lib-rather-than-usr-lib64.patch

# Mageia-specific patches
# Set up defaults for the Koji CLI client
Patch1001: mageia-koji-cli-config.patch

BuildArch: noarch

Requires: python3-%{name} = %{version}-%{release}

BuildRequires: python3-sphinx
BuildRequires: pkgconfig(systemd)
BuildRequires: pkgconfig

%description
Koji is a system for building and tracking RPMS.  The base package
contains the command-line interface.

%package -n python3-%{name}
Summary: Build system tools python library
Group: Development/Python
%{?python_provide:%python_provide python3-%{name}}
BuildRequires: python3-devel
Requires: python3-rpm
Requires: python3-OpenSSL
Requires: python3-requests
Requires: python3-requests-kerberos
Requires: python3-dateutil
Requires: python3-six
Requires: python3-pycurl
Requires: python3-libcomps
# Python 2 subpackage is dropped
Obsoletes: python2-%{name} < 1.17.0

%description -n python3-%{name}
Koji is a system for building and tracking RPMS.  This package
contains shared libraries.

%package -n python3-%{name}-cli-plugins
Summary: Koji client plugins
Group: System/Packaging
License: LGPLv2
Requires: python3-%{name} = %{version}-%{release}
# Python 2 subpackage is dropped
Obsoletes: python2-%{name}-cli-plugins < 1.17.0

%description -n python3-%{name}-cli-plugins
Plugins to the koji command-line interface

%package hub
Summary: Koji XMLRPC interface
Group: System/Servers
License: LGPLv2 and GPLv2
# rpmdiff lib (from rpmlint) is GPLv2 (only)
Requires: apache
Requires: apache-python3-mod_wsgi
Requires: apache-mod_auth_gssapi
Requires: python3-psycopg2
Requires: python3-%{name} = %{version}-%{release}

%description hub
koji-hub is the XMLRPC interface to the koji database

%package hub-plugins
Summary: Koji hub plugins
Group: System/Servers
License: LGPLv2
Requires: python3-%{name} = %{version}-%{release}
Requires: %{name}-hub = %{version}-%{release}
# (ngompa): Cannot get qpid-proton to build
#Requires: python3-qpid-proton
Requires: cpio

%description hub-plugins
Plugins to the koji XMLRPC interface

%package builder
Summary: Koji RPM builder daemon
Group: System/Packaging
License: LGPLv2
Requires: python3-%{name} = %{version}-%{release}
Requires: mock >= 0.9.14
Requires(pre): shadow-utils
Requires: squashfs-tools
Requires: python3-dnf
Requires: python3-librepo
Requires: python3-multilib
Requires: python3-cheetah
Requires(post): systemd
Requires(preun): systemd
Requires(postun): systemd

Requires: cvs
Requires: subversion
Requires: git-core
Requires: createrepo_c

%description builder
koji-builder is the daemon that runs on build machines and executes
tasks that come through the Koji system.

%package builder-plugins
Summary: Koji builder plugins
Group: System/Packaging
License: LGPLv2
Requires: %{name} = %{version}-%{release}
Requires: %{name}-builder = %{version}-%{release}

%description builder-plugins
Plugins for the koji build daemon

%package vm
Summary: Koji virtual machine management daemon
Group: System/Servers
License: LGPLv2
Requires: python3-%{name} = %{version}-%{release}

Requires(post): systemd
Requires(preun): systemd
Requires(postun): systemd

Requires: python3-libvirt
Requires: libxml2-python3
Requires: virt-clone
Requires: qemu-img

%description vm
koji-vm contains a supplemental build daemon that executes certain tasks in a
virtual machine. This package is not required for most installations.

%package utils
Summary: Koji Utilities
Group: System/Packaging
License: LGPLv2
Requires: python3-psycopg2
Requires: python3-%{name} = %{version}-%{release}

Requires(post): systemd
Requires(preun): systemd
Requires(postun): systemd

%description utils
Utilities for the Koji system

%package web
Summary: Koji Web UI
Group: System/Servers
License: LGPLv2
Requires: apache
Requires: apache-python3-mod_wsgi
Requires: apache-mod_auth_gssapi
Requires: python3-psycopg2
Requires: python3-cheetah
Requires: python3-%{name} = %{version}-%{release}

%description web
koji-web is a web UI to the Koji system.

%prep
%setup -q

%patch0501 -p1

# Mageia patches
%if %{with use_mga_cli_cfg}
%patch1001 -p1 -b .orig-cli~
%endif


%build
# Nothing to build

%install
%make_install PYTHON=%{__python3}

# alter python interpreter in koji CLI
scripts='%{_bindir}/koji %{_sbindir}/kojid %{_sbindir}/kojira %{_sbindir}/koji-shadow
         %{_sbindir}/koji-gc %{_sbindir}/kojivmd %{_sbindir}/koji-sweep-db %{_sbindir}/koji-sidetag-cleanup'
for fn in $scripts ; do
    sed -i 's|#!/usr/bin/python2|#!/usr/bin/python3|' $RPM_BUILD_ROOT$fn
done

%if 0%{?mageia} >= 7
# handle extra byte compilation
extra_dirs='
    %{_prefix}/lib/koji-builder-plugins
    %{_prefix}/koji-hub-plugins
    %{_datadir}/koji-hub
    %{_datadir}/koji-web/lib/kojiweb
    %{_datadir}/koji-web/scripts'
for fn in $extra_dirs ; do
    %py_byte_compile %{__python3} %{buildroot}$fn
done
%endif



%files
%{_bindir}/*
%config(noreplace) %{_sysconfdir}/koji.conf
%dir %{_sysconfdir}/koji.conf.d
%doc docs Authors
%license COPYING LGPL

%files -n python3-%{name}
%{python3_sitelib}/%{name}
%{python3_sitelib}/koji_cli

%files -n python3-%{name}-cli-plugins
%{python3_sitelib}/koji_cli_plugins
# we don't have config files for default plugins yet
#%%dir %{_sysconfdir}/koji/plugins
#%%config(noreplace) %{_sysconfdir}/koji/plugins/*.conf


%files hub
%{_datadir}/koji-hub
%config(noreplace) %{_sysconfdir}/httpd/conf.d/kojihub.conf
%dir %{_sysconfdir}/koji-hub
%config(noreplace) %{_sysconfdir}/koji-hub/hub.conf
%dir %{_sysconfdir}/koji-hub/hub.conf.d
%{_sbindir}/koji-sweep-db
%{_unitdir}/koji-sweep-db.service
%{_unitdir}/koji-sweep-db.timer

%files hub-plugins
%dir %{_prefix}/lib/koji-hub-plugins
%{_prefix}/lib/koji-hub-plugins/*.py*
%{_prefix}/lib/koji-hub-plugins/__pycache__/
%dir %{_sysconfdir}/koji-hub/plugins
%{_sysconfdir}/koji-hub/plugins/*.conf
# (ngompa): Cannot get qpid-proton to build
%exclude %{_prefix}/lib/koji-hub-plugins/protonmsg*
%exclude %{_prefix}/lib/koji-hub-plugins/__pycache__/protonmsg*
%exclude %{_sysconfdir}/koji-hub/plugins/protonmsg*

%files utils
%{_sbindir}/kojira
%{_unitdir}/kojira.service
%{_unitdir}/koji-gc.service
%{_unitdir}/koji-gc.timer
%dir %{_sysconfdir}/kojira
%config(noreplace) %{_sysconfdir}/kojira/kojira.conf
%{_sbindir}/koji-gc
%dir %{_sysconfdir}/koji-gc
%config(noreplace) %{_sysconfdir}/koji-gc/koji-gc.conf
%config(noreplace) %{_sysconfdir}/koji-gc/email.tpl
%{_sbindir}/koji-shadow
%dir %{_sysconfdir}/koji-shadow
%config(noreplace) %{_sysconfdir}/koji-shadow/koji-shadow.conf
%{_sbindir}/koji-sidetag-cleanup

%files web
%{_datadir}/koji-web
%dir %{_sysconfdir}/kojiweb
%config(noreplace) %{_sysconfdir}/kojiweb/web.conf
%config(noreplace) %{_sysconfdir}/httpd/conf.d/kojiweb.conf
%dir %{_sysconfdir}/kojiweb/web.conf.d

%files builder
%{_sbindir}/kojid
%defattr(-,root,root)
%{_unitdir}/kojid.service
%dir %{_sysconfdir}/kojid
%config(noreplace) %{_sysconfdir}/kojid/kojid.conf
%attr(-,kojibuilder,kojibuilder) %{_sysconfdir}/mock/koji

%files builder-plugins
%dir %{_sysconfdir}/kojid/plugins
%config(noreplace) %{_sysconfdir}/kojid/plugins/*.conf
%dir %{_prefix}/lib/koji-builder-plugins
%{_prefix}/lib/koji-builder-plugins/*.py*
%{_prefix}/lib/koji-builder-plugins/__pycache__


%pre builder
/usr/sbin/useradd -r -s /bin/bash -G mock -d /builddir -M kojibuilder 2>/dev/null ||:

%post builder
%systemd_post kojid.service

%preun builder
%systemd_preun kojid.service

%files vm
%{_sbindir}/kojivmd
%dir %{_datadir}/kojivmd
%{_datadir}/kojivmd/kojikamid
%{_unitdir}/kojivmd.service
%dir %{_sysconfdir}/kojivmd
%config(noreplace) %{_sysconfdir}/kojivmd/kojivmd.conf

%post vm
%systemd_post kojivmd.service

%preun vm
%systemd_preun kojivmd.service


%post utils
%systemd_post kojira.service

%preun utils
%systemd_preun kojira.service





%changelog
* Mon Dec 28 2020 ngompa <ngompa> 1.23.0-1.mga8
+ Revision: 1664596
- Rebase to version 1.23.0

* Sun Feb 16 2020 umeabot <umeabot> 1.17.0-3.mga8
+ Revision: 1535857
- Mageia 8 Mass Rebuild

* Sun Oct 13 2019 tv <tv> 1.17.0-2.mga8
+ Revision: 1452777
- rebuild with python 3.8

* Sun Mar 10 2019 ngompa <ngompa> 1.17.0-1.mga7
+ Revision: 1373439
- Update to 1.17.0
- Drop upstream patches
- Switch to Python 3
- Replace our patch with upstream proposed one to use createrepo_c by default

* Wed Jan 30 2019 ngompa <ngompa> 1.16.1-4.mga7
+ Revision: 1361988
- Backport patch to fix Python 3 connection bug

* Wed Jan 09 2019 shlomif <shlomif> 1.16.1-3.mga7
+ Revision: 1353319
- Rebuild for python3 3.7

* Thu Oct 18 2018 ngompa <ngompa> 1.16.1-2.mga7
+ Revision: 1321979
- Fix bad sed that caused python32 dep

* Tue Oct 16 2018 ngompa <ngompa> 1.16.1-1.mga7
+ Revision: 1321163
- Update to 1.16.1

* Thu Sep 20 2018 umeabot <umeabot> 1.16.0-2.mga7
+ Revision: 1279187
- Mageia 7 Mass Rebuild

* Tue Jul 03 2018 ngompa <ngompa> 1.16.0-1.mga7
+ Revision: 1241461
- Update to 1.16.0

* Sun Apr 22 2018 ngompa <ngompa> 1.15.1-2.mga7
+ Revision: 1221040
- Add proposed patch to support setting macros for tags/targets

* Sat Apr 21 2018 ngompa <ngompa> 1.15.1-1.mga7
+ Revision: 1220784
- Upgrade to koji 1.15.1 to fix CVE-2018-1002150

* Tue Dec 19 2017 ngompa <ngompa> 1.15.0-1.mga7
+ Revision: 1183490
- Upgrade to v1.15.0
- Drop backported patches

* Sun Dec 10 2017 ngompa <ngompa> 1.14.0-1.mga7
+ Revision: 1181838
- Rebase to version 1.14.0
- Split out Python API into subpackages and switch CLI to Python 3
- Backport py3 keytab patch (PR#708)
- Backport patches for exit code (issue#696)
- Backport py3 runroot encoding patch (PR#735)
- Backport support for rendering license tag information (PR#686)
- Add patches to properly support functioning with Mock 1.4+ (PR#602)

* Sun May 14 2017 ngompa <ngompa> 1.12.0-2.mga6
+ Revision: 1101048
- Backport patch for kojid for non-SSL auth

* Wed Apr 19 2017 ngompa <ngompa> 1.12.0-1.mga6
+ Revision: 1096749
- Upgrade to v1.12.0
- Drop merged patches
- Move Mageia configuration patches to the end for easier rebasing

* Sat Dec 17 2016 ngompa <ngompa> 1.11.0-3.mga6
+ Revision: 1075744
- Fix broken Requires (shadowutils->shadow-utils)

* Fri Dec 16 2016 ngompa <ngompa> 1.11.0-2.mga6
+ Revision: 1075735
- Downgrading python-krbV dependency to Recommends, as it's a fallback mechanism now

* Mon Dec 12 2016 ngompa <ngompa> 1.11.0-1.mga6
+ Revision: 1074306
- Update to koji 1.11.0
- Add patch to enable picking up username from krb ticket
- Add patch to convert from PyGreSQL to psycopg2

* Sun May 08 2016 ngompa <ngompa> 1.10.1-9.mga6
+ Revision: 1011004
- imported package koji

